[Pkg-mozext-commits] [requestpolicy] 24/280: [refactoring] rename Util to Utils

David Prévot taffit at moszumanska.debian.org
Sat May 2 20:29:55 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository requestpolicy.

commit 413564ea31eed62490458014527c2eeaf7f37d7f
Author: Martin Kimmerle <dev at 256k.de>
Date:   Tue Nov 25 06:01:20 2014 +0100

    [refactoring] rename Util to Utils
---
 src/components/requestpolicyService.js | 4 ++--
 src/content/lib/request.jsm            | 2 +-
 src/content/lib/utils.jsm              | 6 +++---
 src/content/overlay.js                 | 2 +-
 src/content/requestLog.js              | 2 +-
 src/content/settings/setup.js          | 4 ++--
 6 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/src/content/lib/request.jsm b/src/content/lib/request.jsm
index 54b4135..f07c83c 100644
--- a/src/content/lib/request.jsm
+++ b/src/content/lib/request.jsm
@@ -306,7 +306,7 @@ NormalRequest.prototype.checkURISchemes = function() {
       if (!win) {
         throw "The window could not be extracted from aContext.";
       }
-      rp.mod.Util.getChromeWindow(win).requestpolicy.overlay
+      rp.mod.Utils.getChromeWindow(win).requestpolicy.overlay
           .showSchemeNotification(win, scheme);
     } catch (e) {
       rp.mod.Logger.warning(rp.mod.Logger.TYPE_ERROR,
diff --git a/src/content/lib/utils.jsm b/src/content/lib/utils.jsm
index aecb3db..4a372a9 100644
--- a/src/content/lib/utils.jsm
+++ b/src/content/lib/utils.jsm
@@ -21,14 +21,14 @@
  * ***** END LICENSE BLOCK *****
  */
 
-var EXPORTED_SYMBOLS = ["Util"];
+var EXPORTED_SYMBOLS = ["Utils"];
 
 const Ci = Components.interfaces;
 const Cc = Components.classes;
 
 const FIREFOX_ID = "{ec8030f7-c20a-464f-9b0e-13a3a9e97384}";
 
-var Util = {
+var Utils = {
   _versionComparator : Cc["@mozilla.org/xpcom/version-comparator;1"]
       .getService(Ci.nsIVersionComparator),
 
@@ -40,7 +40,7 @@ var Util = {
   lastVersion : "0.0",
   lastAppVersion : "0.0",
 
-  // This is initialized by calling Util.initCurAppVersion().
+  // This is initialized by calling Utils.initCurAppVersion().
   curAppVersion : "0.0",
 
   initCurAppVersion : function() {
diff --git a/src/content/overlay.js b/src/content/overlay.js
index 6822462..e9e8252 100644
--- a/src/content/overlay.js
+++ b/src/content/overlay.js
@@ -153,7 +153,7 @@ requestpolicy.overlay = {
   },
 
   _installToolbarButtonOnce : function() {
-    var util = rp.mod.Util;
+    var util = rp.mod.Utils;
 
     // SeaMonkey users have to use a toolbar button now. At the moment I can't
     // justify a bunch of special cases to support the statusbar when such a
diff --git a/src/content/requestLog.js b/src/content/requestLog.js
index 05d1cb1..b8bbd5b 100644
--- a/src/content/requestLog.js
+++ b/src/content/requestLog.js
@@ -89,7 +89,7 @@ requestpolicy.requestLog = {
       return;
     }
 
-    rp.mod.Util.getChromeWindow(window).gBrowser.addTab(content);
+    rp.mod.Utils.getChromeWindow(window).gBrowser.addTab(content);
   }
 };
 
diff --git a/src/content/settings/setup.js b/src/content/settings/setup.js
index a24e91e..45a9fd6 100644
--- a/src/content/settings/setup.js
+++ b/src/content/settings/setup.js
@@ -83,8 +83,8 @@ function onload() {
   // preferences and also do a rule import based on the old strictness settings.
   // Note: using version 1.0.0a8 instead of 1.0 as that was the last version
   // before this setup window was added.
-  if (Util.compareVersions(Util.lastVersion, '0.0') > 0 &&
-      Util.compareVersions(Util.lastVersion, '1.0.0a8') <= 0) {
+  if (Utils.compareVersions(Utils.lastVersion, '0.0') > 0 &&
+      Utils.compareVersions(Utils.lastVersion, '1.0.0a8') <= 0) {
     if (rpService.prefs.prefHasUserValue('uriIdentificationLevel')) {
       var identLevel = rpService.prefs.getIntPref('uriIdentificationLevel');
     } else {

diff --git a/src/components/requestpolicyService.js b/src/components/requestpolicyService.js
index 48af4d8..68fd94b 100644
--- a/src/components/requestpolicyService.js
+++ b/src/components/requestpolicyService.js
@@ -577,9 +577,9 @@ RequestPolicyService.prototype = {
 
   _initVersionInfo : function() {
     try {
-      const util = rp.mod.Util;
+      const util = rp.mod.Utils;
 
       // Set the last version values in the Util module based on the prefs.
       util.lastVersion = this.prefs.getCharPref("lastVersion");
       util.lastAppVersion = this.prefs.getCharPref("lastAppVersion");
 
@@ -577,9 +577,9 @@ RequestPolicyService.prototype = {
 
-      // Set the last version values in the Util module based on the prefs.
+      // Set the last version values in the Utils module based on the prefs.
       util.lastVersion = this.prefs.getCharPref("lastVersion");
       util.lastAppVersion = this.prefs.getCharPref("lastAppVersion");
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/requestpolicy.git



More information about the Pkg-mozext-commits mailing list